#
# spec file for package hello
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           hello
# How to define macros
%define hello echo "hello world"
Provides:       mailreader
Summary:        A Friendly Greeting Program
License:        GPL-3.0+
Group:          Development/Tools/Other
Version:        2.10
Release:        bp155.3.2.1
Url:            http://www.gnu.org/software/hello
Source0:        ftp://ftp.gnu.org/pub/gnu/hello/hello-%{version}.tar.gz
Source1:        ftp://ftp.gnu.org/pub/gnu/hello/hello-%{version}.tar.gz.sig
# https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=hello&download=1
Source2:        %{name}.keyring
Patch0:         hello-1.3.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  makeinfo
PreReq:         %install_info_prereq
Recommends:     %{name}-lang

%description
The GNU hello program produces a familiar, friendly greeting.  It
allows nonprogrammers to use a classic computer science tool that would
otherwise be unavailable to them.  Because it is protected by the GNU
General Public License, users are free to share and change it.

GNU hello supports many native languages.

%lang_package

%prep
# Use defined macro
%{hello}
%setup -q
%patch0
# force rebuild with non-broken makeinfo
rm -f doc/*.info

%build
export CFLAGS="%{optflags}"
%configure
%if %do_profiling
  make CFLAGS="$CFLAGS %cflags_profile_generate" LDFLAGS="-fprofile-arcs"
  make check
  make clean
  make CFLAGS="$CFLAGS %cflags_profile_feedback" LDFLAGS="-fprofile-arcs"
%else
  make
%endif

%check
make check

%install
%make_install
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-, root, root)
%doc COPYING TODO NEWS README THANKS ABOUT-NLS
%{_bindir}/*
%{_infodir}/*.gz
%{_mandir}/*/*

%files lang -f %{name}.lang

%changelog
* Mon Jan 16 2017 meissner@suse.com
- new keyring fetched from savannah homepage, for new maintainer.
* Sat Jan 17 2015 p.drouand@gmail.com
- Updateto version 2.10
  * The 'Hello, World' message is now part of translations.  The
    translation bug was introduced in release 2.9.
  * Make use of none-recursive build.
  * Removal of user-defined new-style.
  * Include an example how to add a section to a manual page, such as BUGS.
  * Rather than 'fprintf (stderr' use libc 'error()' reporting facility.
  * Start using 'make update-copyright' facility.
  * Generate ChangeLog from git commit logs.
  * Avoid manual page generation errors when cross-compiling.
- Split out translation files into a lang subpackage
- Make main package recommend hello-lang
* Sun Nov 16 2014 meissner@suse.com
- removed gpg-offline usage as its checked by source services.
* Wed Nov 13 2013 sweet_f_a@gmx.de
- update to version 2.9:
  * modernized and improved build system
  * added the possibility of user-defined new-style greetings
  * added support for unicode
  * various translations have been updated
* Mon Feb 18 2013 abergmann@novell.com
- Added GPG Offline checking.
* Thu Jul 26 2012 meissner@suse.com
- buildrequire makeinfo
* Sun Apr 22 2012 puzel@suse.com
- update to version 2.8
  - use newer autotools and friends
  - update translations
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sat Feb  7 2009 schwab@suse.de
- Rebuild broken info file.
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
* Mon Jul  9 2007 meissner@suse.de
- upgraded to version 2.3
  - bugfixes, updates to buildsystem
- now GPLv3 licensed.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Wed Mar 10 2004 meissner@suse.de
- run make check
- added feedback based profiling optimization.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb  7 2003 ke@suse.de
- Use install_info macro [# 23424].
* Tue Jun 11 2002 schwab@suse.de
- Don't package %%{_infodir}/dir.
* Tue Jun 11 2002 ke@suse.de
- Update to version 2.1.1; from NEWS:
  * Automake support.
  * Experimental NLS ("Native Language Support").
  * Translations for ca, da, de, el, eo, es, et, fi, fr, gl, he, hr, hu,
    id, it, ja, ko, lv, nb, nl, nn, pl, pt, pt_BR, ru, sk, sl, sv, tr, and
    uk.
  * Test suite.
  * Add a contrib directory.
  * Manual page, produced with 'help2man'.
  * Create proper copyright statement for all output formats.
  * New greeting message ('-n', '--next-generation').
  * Bugfixes:
  * . GNU hello ('-m') does not loop forever if MAIL environment variable is
    not set.
- spec file: Use DESTDIR; use predefined RPM macros; add %%clean section.
* Sun Feb 20 2000 ke@suse.de
- General spec file cleanup:
- Add group tag.
- ./configure -> %%build.
- Use %%{version} and %%{_infodir} macros.
- Add `#neededforbuild automake' to use the suse_update_config macro.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 16 1998 ke@suse.de
- Use the BuildRoot feature properly.
- Update home site (the Source: tag).
* Sun Sep 14 1997 Karl Eichwalder  <ke@suse.de>
- initial package: version 1.3
